;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "thrift" "20251124.952"
  "Major mode for fbthrift and Apache Thrift files."
  '((emacs "24"))
  :url "https://github.com/facebook/fbthrift"
  :commit "d08a6910d620c8560d2a9af574937d11bfb92388"
  :revdesc "d08a6910d620"
  :keywords '("languages"))
